@@ -123,5 +123,23 @@ class ExpaiModelExplainer:
         with open(filepath, 'r') as f:
             return f.read()
 
+    def what_if(self, old_sample: dict = None, new_sample: dict = None):
+        assert old_sample is not None and new_sample is not None, "You must provide an old and new sample to use this module"
+
+        json = {
+            "old_sample": old_sample,
+            "new_sample": new_sample
+        }
+
+        response = self.sess.request("GET",
+                                    self.server_name + "/api/explain/{}/sample/graphics".format(self.model_id), headers=self.headers, json=json)
+
+        if response.ok:
+            return response.json()['visualizations']['single_force_plot']
+        else:
+            logging.error("There was an error creating the explanation. Please, check the details below and report them to EXPAI if required. \n {}".format(
+                response.json()['message']))
+            return None
+
 
 
