@@ -141,7 +141,7 @@ class ExpaiProject:
             return None
 
     def create_sample(self, sample_path: str = None, sample_name: str = None, sample_separator: str = None, sample_target_col: str = None,
-                      sample_encoding: str = 'utf-8'):
+                      sample_encoding: str = 'utf-8', is_display: bool = False, reference_sample_id: str = None, reference_sample_name: str = None):
         """
         Create a new sample for the project
         :param sample_target_col: target column for the model
@@ -154,13 +154,23 @@ class ExpaiProject:
         assert sample_name is not None, "To create a sample you must give it a sample_name"
         assert sample_path is not None, "To create a sample you must specify the path to the stored file"
         assert sample_separator is not None, "Please, specify the file separator"
-        assert sample_target_col is not None, "Please, specify a target column"
 
+        if is_display is not False:
+            assert reference_sample_id is not None or reference_sample_name is not None, "Please, specify the original sample id or name for this display"
+
+            if reference_sample_id is None:
+                reference_sample_id = self._get_sample_id_from_name(reference_sample_name)
+                if reference_sample_id is None:
+                    logging.error(
+                        "We could not find any sample matching that name. Please, try again or use reference_sample_id as parameter")
+                    return False
 
         data = {"sample_name_des": sample_name,
                 "sample_file_separator_des": sample_separator,
                 "sample_file_encoding_des": sample_encoding,
-                "sample_target_col": sample_target_col}
+                "sample_target_col": sample_target_col,
+                "is_display": 1 if is_display else 0,
+                "original_sample_id": reference_sample_id}
 
         files = {'sample_file': open(sample_path, 'r')}
 
